<?php
namespace Blesta\Core\Util\Modules;

/**
 * Registrar module interface. Defines all methods that a registrar module
 * must implement.
 *
 * @package blesta
 * @subpackage blesta.components.modules
 * @copyright Copyright (c) 2020, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */
interface Registrar
{
    /**
     * Verifies that the provided domain name is available
     *
     * @param string $domain The domain to lookup
     * @param int $module_row_id The ID of the module row to fetch for the current module
     * @return bool True if the domain is available, false otherwise
     */
    public function checkAvailability($domain, $module_row_id = null);

    /**
     * Gets the domain expiration date
     *
     * @param string $domain The domain to lookup
     * @param string $format The format to return the expiration date in
     * @param int $module_row_id The ID of the module row to fetch for the current module
     * @return string The domain expiration date in UTC time in the given format
     */
    public function getExpirationDate($domain, $format = 'Y-m-d H:i:s', $module_row_id = null);

    /**
     * Get a list of the TLDs supported by the registrar module
     *
     * @param int $module_row_id The ID of the module row to fetch for the current module
     * @return array A list of all TLDs supported by the registrar module
     */
    public function getTlds($module_row_id = null);
}
