<?php

namespace Blesta\Core\Util\Tax\Common;

/**
 * Abstract Tax
 *
 * @package blesta
 * @subpackage blesta.core.Util.Tax
 * @copyright Copyright (c) 2020, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */
abstract class AbstractTax
{
    /**
     * @var array An array of errors
     */
    private $errors = [];

    /**
     * Verifies if a given tax ID is valid
     *
     * @param string $tax_id The tax ID to verify
     * @param array $client An array containing the client data associated with the tax ID
     * @return bool True if the given tax ID is valid, false otherwise
     */
    public function validateTaxId($tax_id, $client = null)
    {
        return true;
    }

    /**
     * Fetches the name of the tax ID field
     *
     * @return string The name of the tax ID field
     */
    public function getTaxIdName()
    {
        return null;
    }

    /**
     * Gets the tax information of a given tax ID
     *
     * @param string $tax_id The tax ID from which to obtain the information
     * @param array $client An array containing the client data associated with the tax ID
     * @return array An array containing the tax data
     *
     *  - name The name of the taxpayer
     *  - address The address of the taxpayer
     *  - country The country of the taxpayer
     *  - state The state/province of the taxpayer
     *  - type Whether the taxpayer is an individual or a business
     *  - tax_id The formatted tax ID
     *  - tax_exempt True if the taxpayer is exempt from taxes, false otherwise
     *  - settings A list of additional parameters (optional)
     */
    abstract public function getTaxInformation($tax_id, $client = null);

    /**
     * Gets a list of the countries where these tax requirements apply
     *
     * @return array A list containing the country codes in ISO 3166-1 alpha2
     */
    public function getCountries()
    {
        return [];
    }

    /**
     * Gets a list of the states/provinces where these tax requirements apply
     *
     * @return array A list containing the state/province codes
     */
    public function getRegions()
    {
        return [];
    }

    /**
     * Retrieves any errors associated with the tax api
     *
     * @return array An array of errors
     */
    public function errors()
    {
        return $this->errors;
    }
}
